@@ -7,9 +7,7 @@
 //! ```rust
 //! extern crate termsize;
 //!
-//! termsize::get().map(|size| {
-//!   println!("rows {} cols {}", size.rows, size.cols)
-//! });
+//! termsize::get().map(|size| println!("rows {} cols {}", size.rows, size.cols));
 //! ```
 
 /// Container for number of rows and columns
@@ -22,19 +20,18 @@ pub struct Size {
 }
 
 #[cfg(unix)]
-mod nix;
-#[cfg(unix)]
-pub use self::nix::get;
+#[path = "nix.rs"]
+mod imp;
 
 #[cfg(windows)]
-mod win;
-#[cfg(windows)]
-pub use self::win::get;
+#[path = "win.rs"]
+mod imp;
 
-#[cfg(target_os = "redox")]
-mod redox;
-#[cfg(target_os = "redox")]
-pub use self::redox::get;
+#[cfg(not(any(unix, windows)))]
+#[path = "other.rs"]
+mod imp;
+
+pub use imp::get;
 
 #[cfg(test)]
 mod tests {
